aggregate_line_coverage

Function aggregate_line_coverage 

pub fn aggregate_line_coverage(records: &[&FileCoverage]) -> Option<f64>
Compute a weighted-average line coverage percentage across all files that have coverage data. Returns None if no files have coverage data or if total lines_found is zero.