resolve_coverage_file

Function resolve_coverage_file 

pub fn resolve_coverage_file(config_path: Option<&Path>) -> Option<PathBuf>
Resolve a coverage file path from the environment variable SLOC_COVERAGE_FILE or the provided config path, normalising to an absolute PathBuf.