analyze

Function analyze 

pub fn analyze(
    config: &AppConfig,
    runtime_mode: &str,
    cancel: Option<&AtomicBool>,
    progress: Option<&ProgressCounters>,
) -> Result<AnalysisRun>
Errors

Returns an error if the config is invalid, root paths cannot be walked, or any file analysis step fails in a way that cannot be recovered from.