pub fn read_json(path: &Path) -> Result<AnalysisRun>Expand description
Errors
Returns an error if the file cannot be read or the JSON cannot be parsed.
pub fn read_json(path: &Path) -> Result<AnalysisRun>Returns an error if the file cannot be read or the JSON cannot be parsed.