pub struct RegistryEntry {Show 17 fields
pub run_id: String,
pub timestamp_utc: DateTime<Utc>,
pub project_label: String,
pub input_roots: Vec<String>,
pub json_path: Option<PathBuf>,
pub html_path: Option<PathBuf>,
pub pdf_path: Option<PathBuf>,
pub csv_path: Option<PathBuf>,
pub xlsx_path: Option<PathBuf>,
pub summary: ScanSummarySnapshot,
pub git_branch: Option<String>,
pub git_commit: Option<String>,
pub git_commit_long: Option<String>,
pub git_author: Option<String>,
pub git_tags: Option<String>,
pub git_nearest_tag: Option<String>,
pub git_commit_date: Option<String>,
}Expand description
One entry in the scan registry — one per completed analysis run.
Fields
run_id: Stringtimestamp_utc: DateTime<Utc>project_label: Stringinput_roots: Vec<String>json_path: Option<PathBuf>html_path: Option<PathBuf>pdf_path: Option<PathBuf>csv_path: Option<PathBuf>xlsx_path: Option<PathBuf>summary: ScanSummarySnapshotgit_branch: Option<String>Git branch active at scan time, if the project is a git repo.
git_commit: Option<String>Short git commit SHA active at scan time.
git_commit_long: Option<String>Full-length git commit SHA active at scan time (shown on hover).
Author of the last git commit at scan time.
Comma-separated git tags pointing at HEAD at scan time.
git_nearest_tag: Option<String>Nearest ancestor release tag (output of git describe --tags --abbrev=0).
git_commit_date: Option<String>ISO 8601 author-date of the last git commit at scan time.