pub struct AnalysisRun {Show 15 fields
pub tool: ToolMetadata,
pub environment: EnvironmentMetadata,
pub effective_configuration: AppConfig,
pub input_roots: Vec<String>,
pub summary_totals: SummaryTotals,
pub totals_by_language: Vec<LanguageSummary>,
pub per_file_records: Vec<FileRecord>,
pub skipped_file_records: Vec<FileRecord>,
pub warnings: Vec<String>,
pub submodule_summaries: Vec<SubmoduleSummary>,
pub git_commit_short: Option<String>,
pub git_commit_long: Option<String>,
pub git_branch: Option<String>,
pub git_commit_author: Option<String>,
pub git_tags: Option<String>,
}Fields
tool: ToolMetadataenvironment: EnvironmentMetadataeffective_configuration: AppConfiginput_roots: Vec<String>summary_totals: SummaryTotalstotals_by_language: Vec<LanguageSummary>per_file_records: Vec<FileRecord>skipped_file_records: Vec<FileRecord>warnings: Vec<String>submodule_summaries: Vec<SubmoduleSummary>Non-empty only when discovery.submodule_breakdown is enabled.
git_commit_short: Option<String>Short git commit SHA (7 chars) at scan time, if the project is a git repo.
git_commit_long: Option<String>Full git commit SHA at scan time, if the project is a git repo.
git_branch: Option<String>Git branch active at scan time, if the project is a git repo.
Author of the last git commit at scan time.
Comma-separated git tags pointing at HEAD at scan time.